@@ -2,7 +2,6 @@
 ###
 # XML::SAX::Writer - SAX2 XML Writer
 # Robin Berjon <robin@knowscape.com>
-# 26/11/2001 - v0.01
 ###
 
 package XML::SAX::Writer;
@@ -14,7 +13,7 @@ use XML::Filter::BufferText qw();
 @XML::SAX::Writer::Exception::ISA = qw(XML::SAX::Exception);
 
 use vars qw($VERSION %DEFAULT_ESCAPE %COMMENT_ESCAPE);
-$VERSION = '0.41';
+$VERSION = '0.42';
 
 %DEFAULT_ESCAPE = (
                     '&'     => '&amp;',
@@ -200,7 +199,7 @@ package XML::SAX::Writer::StringConsumer;
 #-------------------------------------------------------------------#
 sub new {
     my $self = shift->SUPER::new( @_ );
-    $$self = '';
+    ${${$self}} = '';
     return $self;
 }
 #-------------------------------------------------------------------#
@@ -208,13 +207,13 @@ sub new {
 #-------------------------------------------------------------------#
 # output
 #-------------------------------------------------------------------#
-sub output { ${$_[0]}.= pop }
+sub output { ${${$_[0]}} .= $_[1] }
 #-------------------------------------------------------------------#
 
 #-------------------------------------------------------------------#
 # finalize
 #-------------------------------------------------------------------#
-sub finalize { $_[0] }
+sub finalize { ${$_[0]} }
 #-------------------------------------------------------------------#
 
 #,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,#
